#!/usr/bin/env python
# -*- coding:utf-8 -*-
"""
@Version: 2.0.0
@Project: Secure-Multi-Party-Computation-Protocol
@Author: Zhan Shi
@Time  : 2022/5/6 13:26
@File: __init__.py
@License: MIT
"""
from smpcp import SecureMultiPartyComputationProtocol
from smpcp import CloudPlatform
from smpcp import CloudPlatformThird

__name__ = 'smpcp'
